@@ -12,7 +12,7 @@
 %%
 
 -module(wings_pref).
--export([init/0,finish/0,load/0,
+-export([init/0,finish/0,load/0, get_dir/0,
 	 lowpass/2,
 	 get_value/1,get_value/2,set_value/2,set_default/2,
 	 delete_value/1,
@@ -61,6 +61,17 @@ load() ->
 	    end
     end.
 
+get_dir() ->
+    PFile = case get_value(pref_directory) of
+		undefined -> 
+		    File = get_pref_directory("backup_prefs.txt"),
+		    set_value(pref_directory,File),
+		    File;
+		File -> File
+	    end,
+    filename:dirname(PFile).
+
+
 %%%% Restore window layout on MS Windows
 win32_window_layout() ->
     Max = get_value(win32_start_maximized),
@@ -367,6 +378,7 @@ defaults() ->
      {constrain_axes,true},
      {mini_axis,true},
      {force_show_along_grid,false},
+     {ground_grid_amount, ?GROUND_GRID_AMOUNT},
      {force_ortho_along_axis,false},
      {body_hilite,true},
      {auto_rotate_angle,1.0},
